Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(254)

Unified Diff: chrome/browser/renderer_host/browser_render_process_host.h

Issue 6201005: Initial support for partitioning cookies for isolated apps. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Refactor to use ContentBrowserClient. Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/browser_render_process_host.h
diff --git a/chrome/browser/renderer_host/browser_render_process_host.h b/chrome/browser/renderer_host/browser_render_process_host.h
index 8d969d1e1f3305cf69e4be6bfa8b0cd158fd9435..23a3384057f122724ec5eb93cf9b7f3a09e90c53 100644
--- a/chrome/browser/renderer_host/browser_render_process_host.h
+++ b/chrome/browser/renderer_host/browser_render_process_host.h
@@ -16,6 +16,7 @@
#include "base/scoped_callback_factory.h"
#include "base/scoped_ptr.h"
#include "base/timer.h"
+#include "chrome/common/extensions/extension.h"
#include "content/browser/child_process_launcher.h"
#include "content/browser/renderer_host/render_process_host.h"
#include "content/common/notification_observer.h"
@@ -52,6 +53,12 @@ class BrowserRenderProcessHost : public RenderProcessHost,
explicit BrowserRenderProcessHost(Profile* profile);
~BrowserRenderProcessHost();
+ // Whether this process is associated with an installed app.
+ const Extension* installed_app() const { return installed_app_; }
+ void set_installed_app(const Extension* installed_app) {
+ installed_app_ = installed_app;
+ }
+
// RenderProcessHost implementation (public portion).
virtual bool Init(bool is_accessibility_enabled, bool is_extensions_process);
virtual int GetNextRoutingID();
@@ -199,7 +206,10 @@ class BrowserRenderProcessHost : public RenderProcessHost,
// when running in single-process mode.
bool extension_process_;
- // Usedt to launch and terminate the process without blocking the UI thread.
+ // The Extension for the hosted or packaged app if any, NULL otherwise.
+ scoped_refptr<const Extension> installed_app_;
+
+ // Used to launch and terminate the process without blocking the UI thread.
scoped_ptr<ChildProcessLauncher> child_process_;
// Messages we queue while waiting for the process handle. We queue them here

Powered by Google App Engine
This is Rietveld 408576698